@@ -60,31 +60,32 @@
      tINT = 276,
      tLN = 277,
      tLOG10 = 278,
-     tNOT = 279,
-     tOR = 280,
-     tPI = 281,
-     tPMT = 282,
-     tPV = 283,
-     tRAND = 284,
-     tRATE = 285,
-     tSIN = 286,
-     tSINH = 287,
-     tSLN = 288,
-     tSQRT = 289,
-     tSYD = 290,
-     tTAN = 291,
-     tTANH = 292,
-     tTERM = 293,
-     tU16 = 294,
-     tU32 = 295,
-     tXNOR = 296,
-     tXOR = 297,
-     tRCL = 298,
-     tSTO = 299,
-     tCLR = 300,
-     tINUMBER = 301,
-     tDNUMBER = 302,
-     POS = 303
+     tLOG2 = 279,
+     tNOT = 280,
+     tOR = 281,
+     tPI = 282,
+     tPMT = 283,
+     tPV = 284,
+     tRAND = 285,
+     tRATE = 286,
+     tSIN = 287,
+     tSINH = 288,
+     tSLN = 289,
+     tSQRT = 290,
+     tSYD = 291,
+     tTAN = 292,
+     tTANH = 293,
+     tTERM = 294,
+     tU16 = 295,
+     tU32 = 296,
+     tXNOR = 297,
+     tXOR = 298,
+     tRCL = 299,
+     tSTO = 300,
+     tCLR = 301,
+     tINUMBER = 302,
+     tDNUMBER = 303,
+     POS = 304
    };
 #endif
 /* Tokens.  */
@@ -109,43 +110,44 @@
 #define tINT 276
 #define tLN 277
 #define tLOG10 278
-#define tNOT 279
-#define tOR 280
-#define tPI 281
-#define tPMT 282
-#define tPV 283
-#define tRAND 284
-#define tRATE 285
-#define tSIN 286
-#define tSINH 287
-#define tSLN 288
-#define tSQRT 289
-#define tSYD 290
-#define tTAN 291
-#define tTANH 292
-#define tTERM 293
-#define tU16 294
-#define tU32 295
-#define tXNOR 296
-#define tXOR 297
-#define tRCL 298
-#define tSTO 299
-#define tCLR 300
-#define tINUMBER 301
-#define tDNUMBER 302
-#define POS 303
+#define tLOG2 279
+#define tNOT 280
+#define tOR 281
+#define tPI 282
+#define tPMT 283
+#define tPV 284
+#define tRAND 285
+#define tRATE 286
+#define tSIN 287
+#define tSINH 288
+#define tSLN 289
+#define tSQRT 290
+#define tSYD 291
+#define tTAN 292
+#define tTANH 293
+#define tTERM 294
+#define tU16 295
+#define tU32 296
+#define tXNOR 297
+#define tXOR 298
+#define tRCL 299
+#define tSTO 300
+#define tCLR 301
+#define tINUMBER 302
+#define tDNUMBER 303
+#define POS 304
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 39 "./lr_parser.y"
+#line 38 "./lr_parser.y"
 {
   int int_t[MP_SIZE];
 }
 /* Line 1489 of yacc.c.  */
-#line 149 "lr_parser.tab.h"
+#line 151 "lr_parser.tab.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
